============
Installation
============

At the command line::

    $ easy_install pyinstapaper

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv pyinstapaper
    $ pip install pyinstapaper
